@@ -4,7 +4,7 @@ use strict;
 
 package Brickyard::Role::Plugin;
 BEGIN {
-  $Brickyard::Role::Plugin::VERSION = '1.103640';
+  $Brickyard::Role::Plugin::VERSION = '1.110020';
 }
 
 # ABSTRACT: Role to use for plugins
@@ -12,9 +12,12 @@ use Role::Basic;
 
 sub new {
     my $class = shift;
-    bless { (@_ == 1 && ref($_[0]) eq 'HASH' ? %{ $_[0] } : @_), }, $class;
+    bless {@_}, $class;
 }
 
+# Can't use Class::Accessor::Lite to generate this because Role::Basic would
+# see that it was 'imported' from another package and so would not apply it.
+
 sub brickyard {
     $_[0]->{brickyard} = $_[1] if @_ == 2;
     $_[0]->{brickyard};
@@ -31,7 +34,7 @@ Brickyard::Role::Plugin - Role to use for plugins
 
 =head1 VERSION
 
-version 1.103640
+version 1.110020
 
 =head1 SYNOPSIS
 
@@ -43,8 +46,8 @@ version 1.103640
 
 =head2 new
 
-Constructs a new object. Takes an optional hash or hash reference of arguments
-to initialize the object.
+Constructs a new object. Takes an optional hash of arguments to initialize the
+object.
 
 =head2 brickyard
 
